##  Advanced Integration
This release enables financial data to be pulled from Apptio into SAP LeanIX, giving customers a combined dataset with accuracy in both platforms. Customers will also be able to analyze time-based cost metrics in SAP LeanIX.
